summaryrefslogtreecommitdiff
path: root/lib/stdalign.in.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/stdalign.in.h')
-rw-r--r--lib/stdalign.in.h14
1 files changed, 8 insertions, 6 deletions
diff --git a/lib/stdalign.in.h b/lib/stdalign.in.h
index 16213d216..41dd14328 100644
--- a/lib/stdalign.in.h
+++ b/lib/stdalign.in.h
@@ -1,6 +1,6 @@
-/* A substitute for ISO C 1x <stdalign.h>.
+/* A substitute for ISO C11 <stdalign.h>.
- Copyright 2011 Free Software Foundation, Inc.
+ Copyright 2011-2012 Free Software Foundation, Inc.
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
@@ -21,12 +21,14 @@
#ifndef _GL_STDALIGN_H
#define _GL_STDALIGN_H
/* ISO C1X <stdalign.h> for platforms that lack it.
References:
- ISO C1X <http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1570.pdf>
+ ISO C11 (latest free draft
+ <http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1570.pdf>)
sections 6.5.3.4, 6.7.5, 7.15.
- C++0X <http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2011/n3242.pdf>
+ C++11 (latest free draft
+ <http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2011/n3242.pdf>)
section 18.10. */
/* alignof (TYPE), also known as _Alignof (TYPE), yields the alignment
@@ -68,7 +70,7 @@
To be portable to Sun C 5.11, do not align auto variables to
anything stricter than their default alignment.
- The following draft C1X requirements are not supported here:
+ The following C11 requirements are not supported here:
- If A is zero, alignas has no effect.
- alignas can be used multiple times; the strictest one wins.
@@ -21,12 +21,14 @@
#ifndef _GL_STDALIGN_H
#define _GL_STDALIGN_H
-/* ISO C1X <stdalign.h> for platforms that lack it.
+/* ISO C11 <stdalign.h> for platforms that lack it.
References: